@@ -5,7 +5,7 @@ from sqlalchemy.orm import Mapper, class_mapper
 from sqlalchemy.sql.operators import ColumnOperators
 from sqlalchemy.dialects import postgresql
 
-__version__ = '0.2.1'
+__version__ = '0.2.2'
 
 def copy_to(source, dest, engine, **flags):
     """Export a query or select to a file. For flags, see the PostgreSQL
@@ -50,11 +50,15 @@ def copy_from(source, dest, engine, **flags):
     :param dest: SQLAlchemy model or table
     :param engine: SQLAlchemy engine
     """
-    name = dest.__table__.fullname if is_model(dest) else dest.fullname
+    tbl = dest.__table__ if is_model(dest) else dest
     conn = engine.raw_connection()
     cursor = conn.cursor()
     formatted_flags = '({})'.format(format_flags(flags)) if flags else ''
-    copy = 'COPY {} FROM STDOUT {}'.format(name, formatted_flags)
+    copy = 'COPY "{}"."{}" FROM STDIN {}'.format(
+        tbl.schema or 'public',
+        tbl.name,
+        formatted_flags,
+    )
     cursor.copy_expert(copy, source)
     conn.commit()
     conn.close()
